Changelog
=========

0.2.0
-----
    - Added support for blacklist (.BLACKLIST property). See tests for details.
    - ``bottle_gui()`` function renamed to just ``gui()``. There was package named `bottle_gui` with source `bottle_gui.py`` with function `bottle_gui`. This is imho better.

0.1.3
-----
    - Paths are now sorted alphabetically.

0.1.2
-----
    - Fixed bug in MANIFEST.in.

0.1.0
-----
    - Project created.
